@@ -113,6 +113,7 @@ class TensorDot(Function, Module):
             grad_B = xp.transpose(grad_B, perm) 
         return grad_A, grad_B
 
+
 class EinSum(Function, Module):
     name = "EinSum"
     def __init__(self, subscripts: str, optimize=False):
@@ -125,18 +126,21 @@ class EinSum(Function, Module):
     def forward(self, *operands: xp.ndarray) -> xp.ndarray:
         self.operand_shapes = [op.shape for op in operands]
         self.input_operands = operands
-        self.parent_tensors = operands 
         if opt_einsum is not None and self.optimize:
             if self.forward_path is None:
                 dummy_arrays = [xp.zeros(shape) for shape in self.operand_shapes]
-                self.forward_path = opt_einsum.contract_path(self.subscripts, *dummy_arrays, optimize='auto')
-            return opt_einsum.contract(self.subscripts, *operands, 
-                                     backend='cupy' if xp.__name__ == 'cupy' else 'numpy',
-                                     optimize=self.forward_path)
-        return xp.einsum(self.subscripts, *operands, optimize=self.optimize)
+                # contract_path returns (path, path_info)
+                self.forward_path, _ = opt_einsum.contract_path(
+                    self.subscripts, *dummy_arrays, optimize='auto'
+                )
+            return opt_einsum.contract(
+                self.subscripts, *operands, 
+                backend='cupy' if xp.__name__ == 'cupy' else 'numpy',
+                optimize=self.forward_path
+            )
+        else:
+            return xp.einsum(self.subscripts, *operands, optimize=self.optimize)
     def backward(self, grad_output: xp.ndarray):
-        if not hasattr(self, 'parent_tensors'):
-            return tuple()
         grads = []
         if '->' in self.subscripts:
             inputs_str, output_str = self.subscripts.split('->')
@@ -146,28 +150,37 @@ class EinSum(Function, Module):
             all_indices = ''.join(input_specs)
             output_str = ''.join([idx for idx in set(all_indices) if all_indices.count(idx) == 1])
         for i, tensor in enumerate(self.parent_tensors):
-            if hasattr(tensor, 'requires_grad') and not tensor.requires_grad:
+            if not tensor.requires_grad:
                 grads.append(None)
-                continue
+                continue 
             grad_operands = [grad_output]
-            grad_specs = [output_str] 
+            grad_specs = [output_str]
             for j, operand in enumerate(self.parent_tensors):
                 if j != i:
-                    grad_operands.append(getattr(operand, 'data', operand))
+                    grad_operands.append(operand.data)
                     grad_specs.append(input_specs[j])
             grad_equation = ','.join(grad_specs) + '->' + input_specs[i]
             if opt_einsum is not None and self.optimize:
                 if grad_equation not in self.backward_paths:
-                    dummy_shapes = [grad_output.shape] + [getattr(op, 'data', op).shape 
-                                                         for j, op in enumerate(self.parent_tensors) if j != i]
+                    dummy_shapes = [grad_output.shape]
+                    for j, operand in enumerate(self.parent_tensors):
+                        if j != i:
+                            dummy_shapes.append(operand.data.shape)
                     dummy_arrays = [xp.zeros(shape) for shape in dummy_shapes]
-                    self.backward_paths[grad_equation] = opt_einsum.contract_path(grad_equation, *dummy_arrays, optimize='auto')
-                grad = opt_einsum.contract(grad_equation, *grad_operands,
-                                         backend='cupy' if xp.__name__ == 'cupy' else 'numpy',
-                                         optimize=self.backward_paths[grad_equation])
+                    # contract_path returns (path, path_info)
+                    path, _ = opt_einsum.contract_path(
+                        grad_equation, *dummy_arrays, optimize='auto'
+                    )
+                    self.backward_paths[grad_equation] = path
+                grad = opt_einsum.contract(
+                    grad_equation, *grad_operands,
+                    backend='cupy' if xp.__name__ == 'cupy' else 'numpy',
+                    optimize=self.backward_paths[grad_equation]
+                )
             else:
-                grad = xp.einsum(grad_equation, *grad_operands, optimize=self.optimize)   
-            grads.append(self._handle_broadcasting(grad, self.operand_shapes[i]))
+                grad = xp.einsum(grad_equation, *grad_operands, optimize=self.optimize)
+            grad = self._handle_broadcasting(grad, self.operand_shapes[i])
+            grads.append(grad)
         return tuple(grads)
     def _handle_broadcasting(self, grad, original_shape):
         if grad.shape == original_shape:
@@ -179,6 +192,7 @@ class EinSum(Function, Module):
             if orig_dim == 1 and grad_dim > 1:
                 grad = grad.sum(axis=i, keepdims=True)
         return grad
+    
 
 class Transpose(Function, Module):
     name = "Transpose"
